@@ -20,16 +20,23 @@
 This module defines the :class:`FCIL1cNCFileHandler` file handler, to
 be used for reading Meteosat Third Generation (MTG) Flexible Combined
 Imager (FCI) Level-1c data.  FCI will fly
-on the MTG Imager (MTG-I) series of satellites, scheduled to be launched
-in 2022 by the earliest.  For more information about FCI, see `EUMETSAT`_.
+on the MTG Imager (MTG-I) series of satellites, with the first satellite (MTG-I1)
+scheduled to be launched on the 13th of December 2022.
+For more information about FCI, see `EUMETSAT`_.
 
-For simulated test data to be used with this reader, see `test data release`_.
+For simulated test data to be used with this reader, see `test data releases`_.
 For the Product User Guide (PUG) of the FCI L1c data, see `PUG`_.
 
 .. note::
     This reader currently supports Full Disk High Spectral Resolution Imagery
-    (FDHSI) files. Support for High Spatial Resolution Fast Imagery (HRFI) files
-    will be implemented when corresponding test datasets will be available.
+    (FDHSI) and High Spatial Resolution Fast Imagery (HRFI) data in full-disc ("FD") scanning mode.
+    If the user provides a list of both FDHSI and HRFI files from the same repeat cycle to the Satpy ``Scene``,
+    Satpy will automatically read the channels from the source with the finest resolution,
+    i.e. from the HRFI files for the vis_06, nir_22, ir_38, and ir_105 channels.
+    If needed, the desired resolution can be explicitly requested using e.g.:
+    ``scn.load(['vis_06'], resolution=1000)``.
+
+    Note that RSS data is not supported yet.
 
 Geolocation is based on information from the data files.  It uses:
 
@@ -99,7 +106,7 @@ All auxiliary data can be obtained by prepending the channel name such as
 
 .. _PUG: https://www-cdn.eumetsat.int/files/2020-07/pdf_mtg_fci_l1_pug.pdf
 .. _EUMETSAT: https://www.eumetsat.int/mtg-flexible-combined-imager  # noqa: E501
-.. _test data release: https://www.eumetsat.int/simulated-mtg-fci-l1c-enhanced-non-nominal-datasets
+.. _test data releases: https://www.eumetsat.int/mtg-test-data
 """
 
 from __future__ import absolute_import, division, print_function, unicode_literals
@@ -134,6 +141,15 @@ AUX_DATA = {
     'swath_direction': 'data/swath_direction',
 }
 
+HIGH_RES_GRID_INFO = {'fci_l1c_hrfi': {'grid_type': '500m',
+                                       'grid_width': 22272},
+                      'fci_l1c_fdhsi': {'grid_type': '1km',
+                                        'grid_width': 11136}}
+LOW_RES_GRID_INFO = {'fci_l1c_hrfi': {'grid_type': '1km',
+                                      'grid_width': 11136},
+                     'fci_l1c_fdhsi': {'grid_type': '2km',
+                                       'grid_width': 5568}}
+
 
 def _get_aux_data_name_from_dsname(dsname):
     aux_data_name = [key for key in AUX_DATA.keys() if key in dsname]
@@ -186,7 +202,7 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         """Initialize file handler."""
         super().__init__(filename, filename_info,
                          filetype_info,
-                         cache_var_size=10000,
+                         cache_var_size=0,
                          cache_handle=True)
         logger.debug('Reading: {}'.format(self.filename))
         logger.debug('Start: {}'.format(self.start_time))
@@ -204,22 +220,45 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         """Get end time."""
         return self.filename_info['end_time']
 
-    def get_segment_position_info(self):
-        """Get the vertical position and size information of the chunk (aka segment) for both 1km and 2km grids.
+    def get_channel_measured_group_path(self, channel):
+        """Get the channel's measured group path."""
+        if self.filetype_info['file_type'] == 'fci_l1c_hrfi':
+            channel += '_hr'
+        measured_group_path = 'data/{}/measured'.format(channel)
 
-        This is used in the GEOVariableSegmentYAMLReader to compute optimal chunk sizes for missing chunks.
+        return measured_group_path
+
+    def get_segment_position_info(self):
+        """Get information about the size and the position of the segment inside the final image array.
+
+        As the final array is composed by stacking segments vertically, the position of a segment
+        inside the array is defined by the numbers of the start (lowest) and end (highest) row of the segment.
+        The row numbering is assumed to start with 1.
+        This info is used in the GEOVariableSegmentYAMLReader to compute optimal segment sizes for missing segments.
+
+        Note: in the FCI terminology, a segment is actually called "chunk". To avoid confusion with the dask concept
+        of chunk, and to be consistent with SEVIRI, we opt to use the word segment.
         """
+        vis_06_measured_path = self.get_channel_measured_group_path('vis_06')
+        ir_105_measured_path = self.get_channel_measured_group_path('ir_105')
+
+        file_type = self.filetype_info['file_type']
+
         segment_position_info = {
-            '1km': {'start_position_row': self['data/vis_04/measured/start_position_row'].item(),
-                    'end_position_row': self['data/vis_04/measured/end_position_row'].item(),
-                    'segment_height': self['data/vis_04/measured/end_position_row'].item() -
-                    self['data/vis_04/measured/start_position_row'].item() + 1,
-                    'segment_width': 11136},
-            '2km': {'start_position_row': self['data/ir_105/measured/start_position_row'].item(),
-                    'end_position_row': self['data/ir_105/measured/end_position_row'].item(),
-                    'segment_height': self['data/ir_105/measured/end_position_row'].item() -
-                    self['data/ir_105/measured/start_position_row'].item() + 1,
-                    'segment_width': 5568}
+            HIGH_RES_GRID_INFO[file_type]['grid_type']: {
+                'start_position_row': self.get_and_cache_npxr(vis_06_measured_path + '/start_position_row').item(),
+                'end_position_row': self.get_and_cache_npxr(vis_06_measured_path + '/end_position_row').item(),
+                'segment_height': self.get_and_cache_npxr(vis_06_measured_path + '/end_position_row').item() -
+                self.get_and_cache_npxr(vis_06_measured_path + '/start_position_row').item() + 1,
+                'grid_width': HIGH_RES_GRID_INFO[file_type]['grid_width']
+            },
+            LOW_RES_GRID_INFO[file_type]['grid_type']: {
+                'start_position_row': self.get_and_cache_npxr(ir_105_measured_path + '/start_position_row').item(),
+                'end_position_row': self.get_and_cache_npxr(ir_105_measured_path + '/end_position_row').item(),
+                'segment_height': self.get_and_cache_npxr(ir_105_measured_path + '/end_position_row').item() -
+                self.get_and_cache_npxr(ir_105_measured_path + '/start_position_row').item() + 1,
+                'grid_width': LOW_RES_GRID_INFO[file_type]['grid_width']
+            }
         }
 
         return segment_position_info
@@ -296,7 +335,7 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         res.attrs.update(attrs)
 
         res.attrs["platform_name"] = self._platform_name_translate.get(
-            self["/attr/platform"], self["/attr/platform"])
+            self["attr/platform"], self["attr/platform"])
 
         # remove unpacking parameters for calibrated data
         if key['calibration'] in ['brightness_temperature', 'reflectance']:
@@ -314,14 +353,14 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
 
     @cached_property
     def orbital_param(self):
-        """Compute the orbital parameters for the current chunk."""
+        """Compute the orbital parameters for the current segment."""
         actual_subsat_lon = float(np.nanmean(self._get_aux_data_lut_vector('subsatellite_longitude')))
         actual_subsat_lat = float(np.nanmean(self._get_aux_data_lut_vector('subsatellite_latitude')))
         actual_sat_alt = float(np.nanmean(self._get_aux_data_lut_vector('platform_altitude')))
-
-        nominal_and_proj_subsat_lon = float(self["data/mtg_geos_projection/attr/longitude_of_projection_origin"])
+        mtg_geos_proj = self.get_and_cache_npxr("data/mtg_geos_projection")
+        nominal_and_proj_subsat_lon = float(mtg_geos_proj.longitude_of_projection_origin)
         nominal_and_proj_subsat_lat = 0
-        nominal_and_proj_sat_alt = float(self["data/mtg_geos_projection/attr/perspective_point_height"])
+        nominal_and_proj_sat_alt = float(mtg_geos_proj.perspective_point_height)
 
         orb_param_dict = {
             'orbital_parameters': {
@@ -356,7 +395,7 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
 
     def _get_aux_data_lut_vector(self, aux_data_name):
         """Load the lut vector of an auxiliary variable."""
-        lut = self[AUX_DATA[aux_data_name]]
+        lut = self.get_and_cache_npxr(AUX_DATA[aux_data_name])
 
         fv = default_fillvals.get(lut.dtype.str[1:], np.nan)
         lut = lut.where(lut != fv)
@@ -372,7 +411,7 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         # get index map
         index_map = self._get_dataset_index_map(_get_channel_name_from_dsname(dsname))
         # subtract minimum of index variable (index_offset)
-        index_map -= np.min(self['index'])
+        index_map -= np.min(self.get_and_cache_npxr('index'))
 
         # get lut values from 1-d vector variable
         lut = self._get_aux_data_lut_vector(_get_aux_data_name_from_dsname(dsname))
@@ -386,13 +425,6 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
 
         return aux
 
-    @staticmethod
-    def get_channel_measured_group_path(channel):
-        """Get the channel's measured group path."""
-        measured_group_path = 'data/{}/measured'.format(channel)
-
-        return measured_group_path
-
     def calc_area_extent(self, key):
         """Calculate area extent for a dataset."""
         # if a user requests a pixel quality or index map before the channel data, the
@@ -408,11 +440,12 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         logger.debug('Row/Cols: {} / {}'.format(nlines, ncols))
 
         # Calculate full globe line extent
-        h = float(self["data/mtg_geos_projection/attr/perspective_point_height"])
+        mtg_geos_proj = self.get_and_cache_npxr("data/mtg_geos_projection")
+        h = float(mtg_geos_proj.perspective_point_height)
 
         extents = {}
         for coord in "xy":
-            coord_radian = self["data/{:s}/measured/{:s}".format(channel_name, coord)]
+            coord_radian = self.get_and_cache_npxr(measured + "/{:s}".format(coord))
 
             # TODO remove this check when old versions of IDPF test data (<v4) are deprecated.
             if coord == "x" and coord_radian.scale_factor > 0:
@@ -475,11 +508,12 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         if key['resolution'] in self._cache:
             return self._cache[key['resolution']]
 
-        a = float(self["data/mtg_geos_projection/attr/semi_major_axis"])
-        h = float(self["data/mtg_geos_projection/attr/perspective_point_height"])
-        rf = float(self["data/mtg_geos_projection/attr/inverse_flattening"])
-        lon_0 = float(self["data/mtg_geos_projection/attr/longitude_of_projection_origin"])
-        sweep = str(self["data/mtg_geos_projection"].sweep_angle_axis)
+        mtg_geos_proj = self.get_and_cache_npxr("data/mtg_geos_projection")
+        a = float(mtg_geos_proj.semi_major_axis)
+        h = float(mtg_geos_proj.perspective_point_height)
+        rf = float(mtg_geos_proj.inverse_flattening)
+        lon_0 = float(mtg_geos_proj.longitude_of_projection_origin)
+        sweep = str(mtg_geos_proj.sweep_angle_axis)
 
         area_extent, nlines, ncols = self.calc_area_extent(key)
         logger.debug('Calculated area extent: {}'
@@ -552,8 +586,8 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
                     data.attrs.get("add_offset", 0))
 
         measured = self.get_channel_measured_group_path(key['name'])
-        data.attrs.update({'radiance_unit_conversion_coefficient': self[measured +
-                                                                        '/radiance_unit_conversion_coefficient']})
+        data.attrs.update({'radiance_unit_conversion_coefficient':
+                          self.get_and_cache_npxr(measured + '/radiance_unit_conversion_coefficient')})
         return data
 
     def calibrate_rad_to_bt(self, radiance, key):
@@ -562,13 +596,13 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
 
         measured = self.get_channel_measured_group_path(key['name'])
 
-        vc = self[measured + "/radiance_to_bt_conversion_coefficient_wavenumber"]
+        vc = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_wavenumber")
 
-        a = self[measured + "/radiance_to_bt_conversion_coefficient_a"]
-        b = self[measured + "/radiance_to_bt_conversion_coefficient_b"]
+        a = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_a")
+        b = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_coefficient_b")
 
-        c1 = self[measured + "/radiance_to_bt_conversion_constant_c1"]
-        c2 = self[measured + "/radiance_to_bt_conversion_constant_c2"]
+        c1 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c1")
+        c2 = self.get_and_cache_npxr(measured + "/radiance_to_bt_conversion_constant_c2")
 
         for v in (vc, a, b, c1, c2):
             if v == v.attrs.get("FillValue",
@@ -591,7 +625,7 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
         """VIS channel calibration."""
         measured = self.get_channel_measured_group_path(key['name'])
 
-        cesi = self[measured + "/channel_effective_solar_irradiance"]
+        cesi = self.get_and_cache_npxr(measured + "/channel_effective_solar_irradiance")
 
         if cesi == cesi.attrs.get(
                 "FillValue", default_fillvals.get(cesi.dtype.str[1:])):
@@ -600,7 +634,8 @@ class FCIL1cNCFileHandler(NetCDF4FileHandler):
                 "cannot produce reflectance for {:s}.".format(measured))
             return radiance * np.nan
 
-        sun_earth_distance = np.mean(self["state/celestial/earth_sun_distance"]) / 149597870.7  # [AU]
+        sun_earth_distance = np.mean(
+            self.get_and_cache_npxr("state/celestial/earth_sun_distance")) / 149597870.7  # [AU]
 
         # TODO remove this check when old versions of IDPF test data (<v5) are deprecated.
         if sun_earth_distance < 0.9 or sun_earth_distance > 1.1:
