@@ -157,9 +157,11 @@ class SCMIFileHandler(BaseFileHandler):
                            'sensor': data.attrs.get('sensor', self.sensor),
                            })
         if 'satellite_longitude' in self.nc.attrs:
-            data.attrs['satellite_longitude'] = self.nc.attrs['satellite_longitude']
-            data.attrs['satellite_latitude'] = self.nc.attrs['satellite_latitude']
-            data.attrs['satellite_altitude'] = self.nc.attrs['satellite_altitude']
+            data.attrs['orbital_parameters'] = {
+                'projection_longitude': self.nc.attrs['satellite_longitude'],
+                'projection_latitude': self.nc.attrs['satellite_latitude'],
+                'projection_altitude': self.nc.attrs['satellite_altitude'],
+            }
 
         scene_id = self.nc.attrs.get('scene_id')
         if scene_id is not None:
