@@ -31,17 +31,16 @@ warned about the quality of the result.
 from datetime import datetime
 
 from .hdf4_utils import HDF4FileHandler
-
-TIME_FORMAT = "%Y%j%H%M%S"
+from .netcdf_utils import NetCDF4FileHandler
 
 
-class SEADASL2HDFFileHandler(HDF4FileHandler):
+class _SEADASL2Base:
     """Simple handler of SEADAS L2 files."""
 
     def __init__(self, filename, filename_info, filetype_info, apply_quality_flags=False):
         """Initialize file handler and determine if data quality flags should be applied."""
         super().__init__(filename, filename_info, filetype_info)
-        self.apply_quality_flags = apply_quality_flags and "l2_flags" in self
+        self.apply_quality_flags = apply_quality_flags and self.l2_flags_var_name in self
 
     def _add_satpy_metadata(self, data):
         data.attrs["sensor"] = self.sensor_names
@@ -57,7 +56,7 @@ class SEADASL2HDFFileHandler(HDF4FileHandler):
         raise ValueError(f"Don't know how to read data for sensors: {self.sensor_names}")
 
     def _platform_name(self):
-        platform = self["/attr/Mission"]
+        platform = self[self.platform_attr_name]
         platform_dict = {'NPP': 'Suomi-NPP',
                          'JPSS-1': 'NOAA-20',
                          'JPSS-2': 'NOAA-21'}
@@ -66,38 +65,93 @@ class SEADASL2HDFFileHandler(HDF4FileHandler):
     @property
     def start_time(self):
         """Get the starting observation time of this file's data."""
-        start_time = self["/attr/Start Time"]
-        return datetime.strptime(start_time[:-3], TIME_FORMAT)
+        start_time = self[self.start_time_attr_name]
+        return datetime.strptime(start_time[:-3], self.time_format)
 
     @property
     def end_time(self):
         """Get the ending observation time of this file's data."""
-        end_time = self["/attr/End Time"]
-        return datetime.strptime(end_time[:-3], TIME_FORMAT)
+        end_time = self[self.end_time_attr_name]
+        return datetime.strptime(end_time[:-3], self.time_format)
 
     @property
     def sensor_names(self):
         """Get sensor for the current file's data."""
         # Example: MODISA or VIIRSN or VIIRSJ1
-        sensor_name = self["/attr/Sensor Name"].lower()
+        sensor_name = self[self.sensor_attr_name].lower()
         if sensor_name.startswith("modis"):
             return {"modis"}
         return {"viirs"}
 
     def get_dataset(self, data_id, dataset_info):
         """Get DataArray for the specified DataID."""
-        file_key = dataset_info.get("file_key", data_id["name"])
-        data = self[file_key]
-        valid_range = data.attrs["valid_range"]
-        data = data.where(valid_range[0] <= data)
-        data = data.where(data <= valid_range[1])
-        if self.apply_quality_flags and not ("lon" in file_key or "lat" in file_key):
-            l2_flags = self["l2_flags"]
-            mask = (l2_flags & 0b00000000010000000000000000000000) != 0
-            data = data.where(~mask)
+        file_key, data = self._get_file_key_and_variable(data_id, dataset_info)
+        data = self._filter_by_valid_min_max(data)
+        data = self._rename_2d_dims_if_necessary(data)
+        data = self._mask_based_on_l2_flags(data)
         for attr_name in ("standard_name", "long_name", "units"):
             val = data.attrs[attr_name]
             if val[-1] == "\x00":
                 data.attrs[attr_name] = data.attrs[attr_name][:-1]
         data = self._add_satpy_metadata(data)
         return data
+
+    def _get_file_key_and_variable(self, data_id, dataset_info):
+        file_keys = dataset_info.get("file_key", data_id["name"])
+        if not isinstance(file_keys, list):
+            file_keys = [file_keys]
+        for file_key in file_keys:
+            try:
+                data = self[file_key]
+                return file_key, data
+            except KeyError:
+                continue
+        raise KeyError(f"Unable to find any of the possible keys for {data_id}: {file_keys}")
+
+    def _rename_2d_dims_if_necessary(self, data_arr):
+        if data_arr.ndim != 2 or data_arr.dims == ("y", "x"):
+            return data_arr
+        return data_arr.rename(dict(zip(data_arr.dims, ("y", "x"))))
+
+    def _filter_by_valid_min_max(self, data_arr):
+        valid_range = self._valid_min_max(data_arr)
+        data_arr = data_arr.where(valid_range[0] <= data_arr)
+        data_arr = data_arr.where(data_arr <= valid_range[1])
+        return data_arr
+
+    def _valid_min_max(self, data_arr):
+        try:
+            return data_arr.attrs["valid_range"]
+        except KeyError:
+            return data_arr.attrs["valid_min"], data_arr.attrs["valid_max"]
+
+    def _mask_based_on_l2_flags(self, data_arr):
+        standard_name = data_arr.attrs.get("standard_name", "")
+        if self.apply_quality_flags and not ("lon" in standard_name or "lat" in standard_name):
+            l2_flags = self[self.l2_flags_var_name]
+            l2_flags = self._rename_2d_dims_if_necessary(l2_flags)
+            mask = (l2_flags & 0b00000000010000000000000000000000) != 0
+            data_arr = data_arr.where(~mask)
+        return data_arr
+
+
+class SEADASL2NetCDFFileHandler(_SEADASL2Base, NetCDF4FileHandler):
+    """Simple handler of SEADAS L2 NetCDF4 files."""
+
+    start_time_attr_name = "/attr/time_coverage_start"
+    end_time_attr_name = "/attr/time_coverage_end"
+    time_format = "%Y-%m-%dT%H:%M:%S.%f"
+    platform_attr_name = "/attr/platform"
+    sensor_attr_name = "/attr/instrument"
+    l2_flags_var_name = "geophysical_data/l2_flags"
+
+
+class SEADASL2HDFFileHandler(_SEADASL2Base, HDF4FileHandler):
+    """Simple handler of SEADAS L2 HDF4 files."""
+
+    start_time_attr_name = "/attr/Start Time"
+    end_time_attr_name = "/attr/End Time"
+    time_format = "%Y%j%H%M%S"
+    platform_attr_name = "/attr/Mission"
+    sensor_attr_name = "/attr/Sensor Name"
+    l2_flags_var_name = "l2_flags"
