@@ -106,8 +106,17 @@ removed on a per-channel basis using
 :func:`satpy.readers.utils.remove_earthsun_distance_correction`.
 
 
+Masking of bad quality scan lines
+---------------------------------
+
+By default bad quality scan lines are masked and replaced with ``np.nan`` for radiance, reflectance and
+brightness temperature calibrations based on the quality flags provided by the data (for details on quality
+flags see `MSG Level 1.5 Image Data Format Description`_ page 109). To disable masking
+``reader_kwargs={'mask_bad_quality_scan_lines': False}`` can be passed to the Scene.
+
+
 Metadata
-^^^^^^^^
+--------
 
 The SEVIRI L1.5 readers provide the following metadata:
 
@@ -449,8 +458,8 @@ class MpefProductHeader(object):
             ('EncodingVersion', np.uint16),
             ('Channel', np.uint8),
             ('ImageLocation', 'S3'),
-            ('GsicsCalMode', np.bool),
-            ('GsicsCalValidity', np.bool),
+            ('GsicsCalMode', np.bool_),
+            ('GsicsCalValidity', np.bool_),
             ('Padding', 'S2'),
             ('OffsetToData', np.uint32),
             ('Padding2', 'S9'),
@@ -922,3 +931,51 @@ def pad_data_vertically(data, final_size, south_bound, north_bound):
     padding_north = get_padding_area(((final_size[0] - north_bound), ncols), data.dtype)
 
     return np.vstack((padding_south, data, padding_north))
+
+
+def _create_bad_quality_lines_mask(line_validity, line_geometric_quality, line_radiometric_quality):
+    """Create bad quality scan lines mask.
+
+    For details on quality flags see `MSG Level 1.5 Image Data Format Description`_
+    page 109.
+
+    Args:
+        line_validity (numpy.ndarray):
+            Quality flags with shape (nlines,).
+        line_geometric_quality (numpy.ndarray):
+            Quality flags with shape (nlines,).
+        line_radiometric_quality (numpy.ndarray):
+            Quality flags with shape (nlines,).
+
+    Returns:
+        numpy.ndarray: Indicating if the scan line is bad.
+    """
+    # Based on missing (2) or corrupted (3) data
+    line_mask = line_validity >= 2
+    line_mask &= line_validity <= 3
+    # Do not use (4)
+    line_mask &= line_radiometric_quality == 4
+    line_mask &= line_geometric_quality == 4
+    return line_mask
+
+
+def mask_bad_quality(data, line_validity, line_geometric_quality, line_radiometric_quality):
+    """Mask scan lines with bad quality.
+
+    Args:
+        data (xarray.DataArray):
+            Channel data
+        line_validity (numpy.ndarray):
+            Quality flags with shape (nlines,).
+        line_geometric_quality (numpy.ndarray):
+            Quality flags with shape (nlines,).
+        line_radiometric_quality (numpy.ndarray):
+            Quality flags with shape (nlines,).
+
+    Returns:
+        xarray.DataArray: data with lines flagged as bad converted to np.nan.
+    """
+    line_mask = _create_bad_quality_lines_mask(line_validity, line_geometric_quality, line_radiometric_quality)
+    line_mask = line_mask[:, np.newaxis]
+    data = data.where(~line_mask, np.nan).astype(np.float32)
+    return data
