@@ -26,6 +26,7 @@ References:
 """
 
 import logging
+import warnings
 from datetime import datetime
 
 import dask.array as da
@@ -295,6 +296,9 @@ class NativeMSGFileHandler(BaseFileHandler):
         self.mda['hrv_number_of_lines'] = int(sec15hd["NumberLinesHRV"]['Value'])
         self.mda['hrv_number_of_columns'] = cols_hrv
 
+        if self.header['15_MAIN_PRODUCT_HEADER']['QQOV']['Value'] == 'NOK':
+            warnings.warn("The quality flag for this file indicates not OK. Use this data with caution!", UserWarning)
+
     def _read_trailer(self):
 
         hdr_size = self.header_type.itemsize
