@@ -284,9 +284,6 @@ class TestHRITJMAFileHandler(unittest.TestCase):
         self.assertEqual(res.attrs['units'], '%')
         self.assertEqual(res.attrs['sensor'], 'ahi')
         self.assertEqual(res.attrs['platform_name'], HIMAWARI8)
-        self.assertEqual(res.attrs['satellite_longitude'], 140.7)
-        self.assertEqual(res.attrs['satellite_latitude'], 0.)
-        self.assertEqual(res.attrs['satellite_altitude'], 35785831.0)
         self.assertDictEqual(res.attrs['orbital_parameters'], {'projection_longitude': 140.7,
                                                                'projection_latitude': 0.,
                                                                'projection_altitude': 35785831.0})
