@@ -37,11 +37,11 @@ InfoDict = Dict[str, Any]
 
 FAKE_BASIC_INFO: InfoDict = {
     'blocklength': 0,
-    'satellite': np.array(['Himawari-8']),
-    'observation_area': np.array(['FLDK']),
-    'observation_start_time': np.array([58413.12523839]),
-    'observation_end_time': np.array([58413.12562439]),
-    'observation_timeline': np.array([300]),
+    'satellite': 'Himawari-8',
+    'observation_area': 'FLDK',
+    'observation_start_time': 58413.12523839,
+    'observation_end_time': 58413.12562439,
+    'observation_timeline': '0300',
 }
 FAKE_DATA_INFO: InfoDict = {
     'blocklength': 50,
@@ -91,10 +91,10 @@ FAKE_ERROR_LINE_INFO: InfoDict = {}
 FAKE_SPARE_INFO: InfoDict = {'blocklength': 0}
 
 
-def _new_unzip(fname):
+def _new_unzip(fname, prefix=''):
     """Fake unzipping."""
     if fname[-3:] == 'bz2':
-        return fname[:-4]
+        return prefix + fname[:-4]
     return fname
 
 
@@ -359,6 +359,23 @@ class TestAHIHSDFileHandler:
                 fh._check_fpos(fp_, fpos, 0, 'header 1')
                 assert len(w) > 0
 
+    def test_is_valid_time(self):
+        """Test that valid times are correctly identified."""
+        assert AHIHSDFileHandler._is_valid_timeline(FAKE_BASIC_INFO['observation_timeline'])
+        assert not AHIHSDFileHandler._is_valid_timeline('65526')
+
+    def test_time_rounding(self):
+        """Test rounding of the nominal time."""
+        mocker = mock.MagicMock()
+        in_date = datetime(2020, 1, 1, 12, 0, 0)
+
+        with mock.patch('satpy.readers.ahi_hsd.AHIHSDFileHandler._is_valid_timeline', mocker):
+            with _fake_hsd_handler() as fh:
+                mocker.return_value = True
+                assert fh._modify_observation_time_for_nominal(in_date) == datetime(2020, 1, 1, 3, 0, 0)
+                mocker.return_value = False
+                assert fh._modify_observation_time_for_nominal(in_date) == datetime(2020, 1, 1, 12, 0, 0)
+
 
 class TestAHICalibration(unittest.TestCase):
     """Test case for various AHI calibration types."""
@@ -541,6 +558,7 @@ def _create_fake_file_handler(in_fname, filename_info=None, filetype_info=None,
         fh_kwargs = {}
     fh = AHIHSDFileHandler(in_fname, filename_info, filetype_info, **fh_kwargs)
 
-    # Check that the filename is altered for bz2 format files
+    # Check that the filename is altered and 2 digit segment prefix added for bz2 format files
     assert in_fname != fh.filename
+    assert str(filename_info['segment']).zfill(2) == fh.filename[0:2]
     return fh
