@@ -23,6 +23,7 @@ from datetime import datetime
 from unittest import mock
 
 import dask.array as da
+import h5py
 import numpy as np
 import xarray as xr
 
@@ -55,12 +56,14 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
         selection = {
             'Grid/IRprecipitation':
             xr.DataArray(
-                da.ones((1, num_rows, num_cols), chunks=1024,
+                da.ones((1, num_cols, num_rows), chunks=1024,
                         dtype=np.float32),
                 attrs={
                     '_FillValue': -9999.9,
                     'units': 'mm/hr',
                     'Units': 'mm/hr',
+                    'badval': h5py.h5r.Reference(),
+                    'badvals': np.array([[h5py.h5r.Reference()]])
                 },
                 dims=('time', 'lon', 'lat')),
         }
