@@ -24,6 +24,8 @@ from collections import OrderedDict
 import h5py
 import numpy as np
 
+from satpy.tests.reader_tests.utils import fill_h5
+
 CTYPE_TEST_ARRAY = (np.random.rand(1856, 3712) * 255).astype(np.uint8)
 CTYPE_TEST_FRAME = (np.arange(100).reshape(10, 10) / 100. * 20).astype(np.uint8)
 CTYPE_TEST_ARRAY[1000:1010, 1000:1010] = CTYPE_TEST_FRAME
@@ -450,32 +452,19 @@ class TestH5NWCSAF(unittest.TestCase):
             "SAFNWC_MSG3_CTTH_201611090800_MSG-N_______.PLAX.CTTH.0.h5",
         )
 
-        def fill_h5(root, stuff):
-            for key, val in stuff.items():
-                if key in ["value", "attrs"]:
-                    continue
-                if "value" in val:
-                    root[key] = val["value"]
-                else:
-                    grp = root.create_group(key)
-                    fill_h5(grp, stuff[key])
-                if "attrs" in val:
-                    for attrs, val in val["attrs"].items():
-                        if isinstance(val, str) and val.startswith(
-                            "<HDF5 object reference>"
-                        ):
-                            root[key].attrs[attrs] = root[val[24:]].ref
-                        else:
-                            root[key].attrs[attrs] = val
+        def cut_h5_object_ref(root, attr):
+            if isinstance(attr, str) and attr.startswith("<HDF5 object reference>"):
+                return root[attr[24:]].ref
+            return attr
 
         h5f = h5py.File(self.filename_ct, mode="w")
-        fill_h5(h5f, fake_ct)
+        fill_h5(h5f, fake_ct, attr_processor=cut_h5_object_ref)
         for attr, val in fake_ct["attrs"].items():
             h5f.attrs[attr] = val
         h5f.close()
 
         h5f = h5py.File(self.filename_ctth, mode="w")
-        fill_h5(h5f, fake_ctth)
+        fill_h5(h5f, fake_ctth, attr_processor=cut_h5_object_ref)
         for attr, val in fake_ctth["attrs"].items():
             h5f.attrs[attr] = val
         h5f.close()
