@@ -154,6 +154,10 @@ class TestHRITMSGFileHandler(TestHRITMSGBase):
             ncols=self.ncols,
             projection_longitude=self.projection_longitude
         )
+        self.reader.mda.update({
+            'segment_sequence_number': 18,
+            'planned_start_segment_number': 1
+        })
 
     def _get_fake_data(self):
         return xr.DataArray(
@@ -208,6 +212,34 @@ class TestHRITMSGFileHandler(TestHRITMSGBase):
         info = setup.get_fake_dataset_info()
         res = self.reader.get_dataset(key, info)
 
+        # Test method calls
+        new_data = np.zeros_like(data.data).astype('float32')
+        new_data[:, :] = np.nan
+        expected = data.copy(data=new_data)
+
+        expected['acq_time'] = (
+            'y',
+            setup.get_acq_time_exp(self.start_time, self.nlines)
+        )
+        xr.testing.assert_equal(res, expected)
+        self.assert_attrs_equal(
+            res.attrs,
+            setup.get_attrs_exp(self.projection_longitude)
+        )
+
+    @mock.patch('satpy.readers.seviri_l1b_hrit.HRITFileHandler.get_dataset')
+    @mock.patch('satpy.readers.seviri_l1b_hrit.HRITMSGFileHandler.calibrate')
+    def test_get_dataset_without_masking_bad_scan_lines(self, calibrate, parent_get_dataset):
+        """Test getting the dataset."""
+        data = self._get_fake_data()
+        parent_get_dataset.return_value = mock.MagicMock()
+        calibrate.return_value = data
+
+        key = make_dataid(name='VIS006', calibration='reflectance')
+        info = setup.get_fake_dataset_info()
+        self.reader.mask_bad_quality_scan_lines = False
+        res = self.reader.get_dataset(key, info)
+
         # Test method calls
         expected = data.copy()
         expected['acq_time'] = (
@@ -382,9 +414,9 @@ class TestHRITMSGCalibration(TestFileHandlerCalibrationBase):
         }
         mda = {
             'image_segment_line_quality': {
-                'line_validity': np.zeros(2),
-                'line_radiometric_quality': np.zeros(2),
-                'line_geometric_quality': np.zeros(2)
+                'line_validity': np.array([3, 3]),
+                'line_radiometric_quality': np.array([4, 4]),
+                'line_geometric_quality': np.array([4, 4])
             },
         }
 
@@ -450,3 +482,21 @@ class TestHRITMSGCalibration(TestFileHandlerCalibrationBase):
 
         res = fh.calibrate(counts, calibration)
         xr.testing.assert_allclose(res, expected)
+
+    def test_mask_bad_quality(self, file_handler):
+        """Test the masking of bad quality scan lines."""
+        channel = 'VIS006'
+        expected = self._get_expected(
+            channel=channel,
+            calibration='radiance',
+            calib_mode='NOMINAL',
+            use_ext_coefs=False
+        )
+
+        fh = file_handler
+
+        res = fh._mask_bad_quality(expected)
+        new_data = np.zeros_like(expected.data).astype('float32')
+        new_data[:, :] = np.nan
+        expected = expected.copy(data=new_data)
+        xr.testing.assert_equal(res, expected)
