@@ -160,7 +160,10 @@ def get_fake_mda(nlines, ncols, start_time):
         'coff': 10,
         'loff': 10,
         'image_segment_line_quality': {
-            'line_mean_acquisition': tline
+            'line_mean_acquisition': tline,
+            'line_validity': np.full(nlines, 3),
+            'line_radiometric_quality': np.full(nlines, 4),
+            'line_geometric_quality': np.full(nlines, 4)
         }
     }
 
