@@ -29,6 +29,8 @@ from satpy.tests.reader_tests.test_seviri_base import ORBIT_POLYNOMIALS
 from satpy.tests.reader_tests.test_seviri_l1b_calibration import TestFileHandlerCalibrationBase
 from satpy.tests.utils import assert_attrs_equal, make_dataid
 
+channel_keys_dict = {'VIS006': 'ch1', 'IR_108': 'ch9'}
+
 
 def to_cds_time(time):
     """Convert datetime to (days, msecs) since 1958-01-01."""
@@ -57,6 +59,8 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
         """
         acq_time_day = np.repeat([1, 1], 11).reshape(2, 11)
         acq_time_msec = np.repeat([1000, 2000], 11).reshape(2, 11)
+        line_validity = np.repeat([3, 3], 11).reshape(2, 11)
+        line_geom_radio_quality = np.repeat([4, 4], 11).reshape(2, 11)
         orbit_poly_start_day, orbit_poly_start_msec = to_cds_time(
             np.array([datetime(2019, 12, 31, 18),
                       datetime(2019, 12, 31, 22)],
@@ -74,8 +78,8 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
         scan_time_days, scan_time_msecs = to_cds_time(self.scan_time)
         ds = xr.Dataset(
             {
-                'VIS006': counts.copy(),
-                'IR_108': counts.copy(),
+                'ch1': counts.copy(),
+                'ch9': counts.copy(),
                 'HRV': (('num_rows_hrv', 'num_columns_hrv'), [[1, 2, 3],
                                                               [4, 5, 6],
                                                               [7, 8, 9]]),
@@ -88,6 +92,18 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
                     ('num_rows_vis_ir', 'channels_vis_ir_dim'),
                     acq_time_msec
                 ),
+                'channel_data_visir_data_line_validity': (
+                    ('num_rows_vis_ir', 'channels_vis_ir_dim'),
+                    line_validity
+                ),
+                'channel_data_visir_data_line_geometric_quality': (
+                    ('num_rows_vis_ir', 'channels_vis_ir_dim'),
+                    line_geom_radio_quality
+                ),
+                'channel_data_visir_data_line_radiometric_quality': (
+                    ('num_rows_vis_ir', 'channels_vis_ir_dim'),
+                    line_geom_radio_quality
+                ),
                 'orbit_polynomial_x': (
                     ('orbit_polynomial_dim_row',
                      'orbit_polynomial_dim_col'),
@@ -153,11 +169,12 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
 
             ds.attrs.update(nattrs)
 
-        ds['VIS006'].attrs.update({
+        ds['ch1'].attrs.update({
             'scale_factor': self.gains_nominal[0],
             'add_offset': self.offsets_nominal[0]
         })
-        ds['IR_108'].attrs.update({
+        # IR_108 is dataset with key ch9
+        ds['ch9'].attrs.update({
             'scale_factor': self.gains_nominal[8],
             'add_offset': self.offsets_nominal[8],
         })
@@ -169,7 +186,7 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
             'valid_min': None,
             'valid_max': None
         }
-        for name in ['VIS006', 'IR_108']:
+        for name in ['ch1', 'ch9']:
             ds[name].attrs.update(strip_attrs)
 
         return ds
@@ -236,25 +253,56 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
         fh.ext_calib_coefs = external_coefs
         dataset_id = make_dataid(name=channel, calibration=calibration)
 
-        res = fh.calibrate(fh.nc[channel], dataset_id)
+        key = channel_keys_dict[channel]
+
+        res = fh.calibrate(fh.nc[key], dataset_id)
         xr.testing.assert_allclose(res, expected)
 
-    @pytest.mark.parametrize(
-        ('channel', 'calibration'),
-        [
-            ('VIS006', 'reflectance'),
-            ('IR_108', 'brightness_temperature')
-         ]
-    )
-    def test_get_dataset(self, file_handler, channel, calibration):
-        """Test getting the dataset."""
-        dataset_id = make_dataid(name=channel, calibration=calibration)
+    def test_mask_bad_quality(self, file_handler):
+        """Test masking of bad quality scan lines."""
+        channel = 'VIS006'
+        key = channel_keys_dict[channel]
         dataset_info = {
-            'nc_key': channel,
+            'nc_key': key,
             'units': 'units',
             'wavelength': 'wavelength',
             'standard_name': 'standard_name'
         }
+        expected = self._get_expected(
+            channel=channel,
+            calibration='radiance',
+            calib_mode='NOMINAL',
+            use_ext_coefs=False
+        )
+
+        fh = file_handler
+
+        res = fh._mask_bad_quality(fh.nc[key], dataset_info)
+        new_data = np.zeros_like(expected.data).astype('float32')
+        new_data[:, :] = np.nan
+        expected = expected.copy(data=new_data)
+        xr.testing.assert_allclose(res, expected)
+
+    @pytest.mark.parametrize(
+        ('channel', 'calibration', 'mask_bad_quality_scan_lines'),
+        [
+            ('VIS006', 'reflectance', True),
+            ('VIS006', 'reflectance', False),
+            ('IR_108', 'brightness_temperature', True)
+         ]
+    )
+    def test_get_dataset(self, file_handler, channel, calibration, mask_bad_quality_scan_lines):
+        """Test getting the dataset."""
+        dataset_id = make_dataid(name=channel, calibration=calibration)
+        key = channel_keys_dict[channel]
+        dataset_info = {
+            'nc_key': key,
+            'units': 'units',
+            'wavelength': 'wavelength',
+            'standard_name': 'standard_name'
+        }
+
+        file_handler.mask_bad_quality_scan_lines = mask_bad_quality_scan_lines
         res = file_handler.get_dataset(dataset_id, dataset_info)
 
         # Test scanline acquisition times
@@ -285,6 +333,9 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
         expected['acq_time'] = ('y', [np.datetime64('1958-01-02 00:00:01'),
                                       np.datetime64('1958-01-02 00:00:02')])
         expected = expected[::-1]  # reader flips data upside down
+        if mask_bad_quality_scan_lines:
+            expected = file_handler._mask_bad_quality(expected, dataset_info)
+
         xr.testing.assert_allclose(res, expected)
 
         for key in ['sun_earth_distance_correction_applied',
@@ -296,7 +347,8 @@ class TestNCSEVIRIFileHandler(TestFileHandlerCalibrationBase):
         """Test satellite position if there is no valid orbit polynomial."""
         dataset_id = make_dataid(name='VIS006', calibration='counts')
         dataset_info = {
-            'nc_key': 'VIS006',
+            'name': 'VIS006',
+            'nc_key': 'ch1',
             'units': 'units',
             'wavelength': 'wavelength',
             'standard_name': 'standard_name'
