@@ -25,9 +25,11 @@ from tempfile import mkdtemp
 from unittest.mock import MagicMock, call, patch
 
 import numpy as np
+import pytest
 import xarray as xr
 
 import satpy.readers.yaml_reader as yr
+from satpy._compat import cache
 from satpy.dataset import DataQuery
 from satpy.dataset.dataid import ModifierTuple
 from satpy.readers.file_handlers import BaseFileHandler
@@ -41,7 +43,7 @@ MHS_YAML_READER_DICT = {
                'default_channels': [1, 2, 3, 4, 5],
                'data_identification_keys': {'name': {'required': True},
                                             'frequency_double_sideband':
-                                            {'type': FrequencyDoubleSideBand},
+                                                {'type': FrequencyDoubleSideBand},
                                             'frequency_range': {'type': FrequencyRange},
                                             'resolution': None,
                                             'polarization': {'enum': ['H', 'V']},
@@ -689,7 +691,7 @@ class TestFileFileYAMLReaderMultipleFileTypes(unittest.TestCase):
             # need to copy this because the dataset infos will be modified
             _orig_ids = {key: val.copy() for key, val in orig_ids.items()}
             with patch.dict(self.reader.all_ids, _orig_ids, clear=True), \
-                 patch.dict(self.reader.available_ids, {}, clear=True):
+                    patch.dict(self.reader.available_ids, {}, clear=True):
                 # Add a file handler with resolution property
                 fh = MagicMock(filetype_info={'file_type': ftype},
                                resolution=resol)
@@ -1037,7 +1039,7 @@ class TestGEOSegmentYAMLReader(unittest.TestCase):
         es = created_fhs['ft1'][0].filetype_info['expected_segments']
         self.assertEqual(es, 3)
 
-        # check correct FCI chunk number reading into segment
+        # check correct FCI segment (aka chunk in the FCI world) number reading into segment
         fake_fh.filename_info = {'count_in_repeat_cycle': 5}
         created_fhs = reader.create_filehandlers(['fake.nc'])
         es = created_fhs['ft1'][0].filename_info['segment']
@@ -1245,36 +1247,68 @@ class TestGEOSegmentYAMLReader(unittest.TestCase):
         self.assertTrue(proj is projectable)
 
 
-class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
+@pytest.fixture
+@patch.object(yr.GEOVariableSegmentYAMLReader, "__init__", lambda x: None)
+def GVSYReader():
+    """Get a fixture of the GEOVariableSegmentYAMLReader."""
+    from satpy.readers.yaml_reader import GEOVariableSegmentYAMLReader
+    reader = GEOVariableSegmentYAMLReader()
+    reader.segment_infos = dict()
+    reader.segment_heights = cache(reader._segment_heights)
+    return reader
+
+
+@pytest.fixture
+def fake_geswh():
+    """Get a fixture of the patched _get_empty_segment_with_height."""
+    with patch('satpy.readers.yaml_reader._get_empty_segment_with_height') as geswh:
+        yield geswh
+
+
+@pytest.fixture
+def fake_xr():
+    """Get a fixture of the patched xarray."""
+    with patch('satpy.readers.yaml_reader.xr') as xr:
+        yield xr
+
+
+@pytest.fixture
+def fake_mss():
+    """Get a fixture of the patched _find_missing_segments."""
+    with patch('satpy.readers.yaml_reader._find_missing_segments') as mss:
+        yield mss
+
+
+@pytest.fixture
+def fake_adef():
+    """Get a fixture of the patched AreaDefinition."""
+    with patch('satpy.readers.yaml_reader.AreaDefinition') as adef:
+        yield adef
+
+
+class TestGEOVariableSegmentYAMLReader:
     """Test GEOVariableSegmentYAMLReader."""
 
-    @patch.object(yr.FileYAMLReader, "__init__", lambda x: None)
-    @patch('satpy.readers.yaml_reader._get_empty_segment_with_height')
-    @patch('satpy.readers.yaml_reader.xr')
-    @patch('satpy.readers.yaml_reader._find_missing_segments')
-    def test_get_empty_segment(self, mss, xr, geswh):
+    def test_get_empty_segment(self, GVSYReader, fake_mss, fake_xr, fake_geswh):
         """Test execution of (overridden) get_empty_segment inside _load_dataset."""
-        from satpy.readers.yaml_reader import GEOVariableSegmentYAMLReader
-        reader = GEOVariableSegmentYAMLReader()
         # Setup input, and output of mocked functions for first segment missing
         chk_pos_info = {
             '1km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 140,
                     'end_position_row': None,
                     'segment_height': 278,
-                    'segment_width': 5568}
+                    'grid_width': 5568}
         }
         expected_segments = 2
         segment = 2
         aex = [0, 1000, 200, 500]
         ashape = [278, 5568]
-        fh_2, seg2_area = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
+        fh_2, _ = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
 
-        file_handlers = {'filetype1': [fh_2]}
-        reader._extract_segment_location_dicts(file_handlers)
+        GVSYReader.file_handlers = {'filetype1': [fh_2]}
 
         counter = 2
         seg = MagicMock(dims=['y', 'x'])
@@ -1283,32 +1317,28 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
         projectable = MagicMock()
         empty_segment = MagicMock()
         empty_segment.shape = [278, 5568]
-        xr.full_like.return_value = empty_segment
+        fake_xr.full_like.return_value = empty_segment
         dataid = MagicMock()
         ds_info = MagicMock()
 
-        mss.return_value = (counter, expected_segments, slice_list,
-                            failure, projectable)
-        reader._load_dataset(dataid, ds_info, [fh_2])
+        fake_mss.return_value = (counter, expected_segments, slice_list,
+                                 failure, projectable)
+        GVSYReader._load_dataset(dataid, ds_info, [fh_2])
         # the return of get_empty_segment
-        geswh.assert_called_once_with(empty_segment, 139, dim='y')
+        fake_geswh.assert_called_once_with(empty_segment, 139, dim='y')
 
-    @patch.object(yr.FileYAMLReader, "__init__", lambda x: None)
-    @patch('satpy.readers.yaml_reader.AreaDefinition')
-    def test_pad_earlier_segments_area(self, AreaDefinition):
+    def test_pad_earlier_segments_area(self, GVSYReader, fake_adef):
         """Test _pad_earlier_segments_area() for the variable segment case."""
-        from satpy.readers.yaml_reader import GEOVariableSegmentYAMLReader
-        reader = GEOVariableSegmentYAMLReader()
         # setting to 0 or None values that shouldn't be relevant
         chk_pos_info = {
             '1km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 140,
                     'end_position_row': None,
                     'segment_height': 278,
-                    'segment_width': 5568}
+                    'grid_width': 5568}
         }
         expected_segments = 2
         segment = 2
@@ -1316,66 +1346,55 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
         ashape = [278, 5568]
         fh_2, seg2_area = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
 
-        file_handlers = {'filetype1': [fh_2]}
-        reader._extract_segment_location_dicts(file_handlers)
+        GVSYReader.file_handlers = {'filetype1': [fh_2]}
         dataid = 'dataid'
         area_defs = {2: seg2_area}
-        res = reader._pad_earlier_segments_area([fh_2], dataid, area_defs)
-        self.assertEqual(len(res), 2)
+        res = GVSYReader._pad_earlier_segments_area([fh_2], dataid, area_defs)
+        assert len(res) == 2
 
-        # The later vertical chunk (nr. 2) size is 278, which is exactly double the size
-        # of the gap left by the missing first chunk (139, as the second chunk starts at line 140).
-        # Therefore, the new vertical area extent for the first chunk should be
+        # The later vertical segment (nr. 2) size is 278, which is exactly double the size
+        # of the gap left by the missing first segment (139, as the second segment starts at line 140).
+        # Therefore, the new vertical area extent for the first segment should be
         # half of the previous size (1000-500)/2=250.
         # The new area extent lower-left row is therefore 500-250=250
         seg1_extent = (0, 500, 200, 250)
         expected_call = ('fill', 'fill', 'fill', 'some_crs', 5568, 139,
                          seg1_extent)
-        AreaDefinition.assert_called_once_with(*expected_call)
+        fake_adef.assert_called_once_with(*expected_call)
 
-    @patch.object(yr.FileYAMLReader, "__init__", lambda x: None)
-    @patch('satpy.readers.yaml_reader.AreaDefinition')
-    def test_pad_later_segments_area(self, AreaDefinition):
+    def test_pad_later_segments_area(self, GVSYReader, fake_adef):
         """Test _pad_later_segments_area() in the variable padding case."""
-        from satpy.readers.yaml_reader import GEOVariableSegmentYAMLReader
-        reader = GEOVariableSegmentYAMLReader()
-
         chk_pos_info = {
             '1km': {'start_position_row': None,
                     'end_position_row': 11136 - 278,
                     'segment_height': 556,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 5568}}
+                    'grid_width': 5568}}
 
         expected_segments = 2
         segment = 1
         aex = [0, 1000, 200, 500]
         ashape = [556, 11136]
         fh_1, _ = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
-        file_handlers = {'filetype1': [fh_1]}
-        reader._extract_segment_location_dicts(file_handlers)
+        GVSYReader.file_handlers = {'filetype1': [fh_1]}
         dataid = 'dataid'
-        res = reader._pad_later_segments_area([fh_1], dataid)
-        self.assertEqual(len(res), 2)
+        res = GVSYReader._pad_later_segments_area([fh_1], dataid)
+        assert len(res) == 2
 
-        # The previous chunk size is 556, which is exactly double the size of the gap left
-        # by the missing last chunk (278, as the second-to-last chunk ends at line 11136 - 278 )
+        # The previous segment size is 556, which is exactly double the size of the gap left
+        # by the missing last segment (278, as the second-to-last segment ends at line 11136 - 278 )
         # therefore, the new vertical area extent should be half of the previous size (1000-500)/2=250.
         # The new area extent lower-left row is therefore 1000+250=1250
         seg2_extent = (0, 1250, 200, 1000)
         expected_call = ('fill', 'fill', 'fill', 'some_crs', 11136, 278,
                          seg2_extent)
-        AreaDefinition.assert_called_once_with(*expected_call)
+        fake_adef.assert_called_once_with(*expected_call)
 
-    @patch.object(yr.FileYAMLReader, "__init__", lambda x: None)
-    @patch('satpy.readers.yaml_reader.AreaDefinition')
-    def test_pad_later_segments_area_for_multiple_chunks_gap(self, AreaDefinition):
-        """Test _pad_later_segments_area() in the variable padding case for multiple gaps with multiple chunks."""
-        from satpy.readers.yaml_reader import GEOVariableSegmentYAMLReader
-        reader = GEOVariableSegmentYAMLReader()
+    def test_pad_later_segments_area_for_multiple_segments_gap(self, GVSYReader, fake_adef):
+        """Test _pad_later_segments_area() in the variable padding case for multiple gaps with multiple segments."""
 
         def side_effect_areadef(a, b, c, crs, width, height, aex):
             m = MagicMock()
@@ -1384,17 +1403,17 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
             m.crs = crs
             return m
 
-        AreaDefinition.side_effect = side_effect_areadef
+        fake_adef.side_effect = side_effect_areadef
 
         chk_pos_info = {
             '1km': {'start_position_row': 11136 - 600 - 100 + 1,
                     'end_position_row': 11136 - 600,
                     'segment_height': 100,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 5568}}
+                    'grid_width': 5568}}
         expected_segments = 8
         segment = 1
         aex = [0, 1000, 200, 500]
@@ -1404,11 +1423,11 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
             '1km': {'start_position_row': 11136 - 300 - 100 + 1,
                     'end_position_row': 11136 - 300,
                     'segment_height': 100,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 5568}}
+                    'grid_width': 5568}}
         segment = 4
         fh_4, _ = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
 
@@ -1416,46 +1435,44 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
             '1km': {'start_position_row': 11136 - 100 + 1,
                     'end_position_row': None,
                     'segment_height': 100,
-                    'segment_width': 11136},
+                    'grid_width': 11136},
             '2km': {'start_position_row': 0,
                     'end_position_row': 0,
                     'segment_height': 0,
-                    'segment_width': 5568}}
+                    'grid_width': 5568}}
         segment = 8
         fh_8, _ = _create_mocked_fh_and_areadef(aex, ashape, expected_segments, segment, chk_pos_info)
 
-        file_handlers = {'filetype1': [fh_1, fh_4, fh_8]}
-
-        reader._extract_segment_location_dicts(file_handlers)
+        GVSYReader.file_handlers = {'filetype1': [fh_1, fh_4, fh_8]}
         dataid = 'dataid'
-        res = reader._pad_later_segments_area([fh_1, fh_4, fh_8], dataid)
-        self.assertEqual(len(res), 8)
+        res = GVSYReader._pad_later_segments_area([fh_1, fh_4, fh_8], dataid)
+        assert len(res) == 8
 
-        # Regarding the chunk sizes:
-        # First group of missing chunks:
-        # The end position row of the gap is the start row of the last available chunk-1:11136-300-100+1-1=10736
-        # The start position row of the gap is the end row fo the first available chunk+1: 11136-600+1=10837
+        # Regarding the segment sizes:
+        # First group of missing segments:
+        # The end position row of the gap is the start row of the last available segment-1:11136-300-100+1-1=10736
+        # The start position row of the gap is the end row fo the first available segment+1: 11136-600+1=10837
         # hence the gap is 10736-10537+1=200 px high
-        # The 200px have to be split between two missing chunks, the most equal way to do it is with
+        # The 200px have to be split between two missing segments, the most equal way to do it is with
         # sizes 100: 100+100=200
         # Second group:
-        # The end position row of the gap is the start row of the last chunk -1: 11136-100+1-1=11036
-        # The start position row of the gap is the end row fo the first chunk +1: 11136-300+1=10837
+        # The end position row of the gap is the start row of the last segment -1: 11136-100+1-1=11036
+        # The start position row of the gap is the end row fo the first segment +1: 11136-300+1=10837
         # hence the gap is 11036-10837+1=200 px high
-        # The 200px have to be split between three missing chunks, the most equal way to do it is with
+        # The 200px have to be split between three missing segments, the most equal way to do it is with
         # sizes 66 and 67: 66+67+67=200
 
         # Regarding the heights:
         # First group:
-        # The first chunk has 100px height and 500 area extent height.
-        # The first padded chunk has 100px height -> 500*100/100=500 area extent height ->1000+500=1500
-        # The second padded chunk has 100px height -> 500*100/100=500 area extent height ->1500+500=2000
+        # The first segment has 100px height and 500 area extent height.
+        # The first padded segment has 100px height -> 500*100/100=500 area extent height ->1000+500=1500
+        # The second padded segment has 100px height -> 500*100/100=500 area extent height ->1500+500=2000
         # Second group:
-        # The first chunk has 100px height and 500 area extent height.
-        # The first padded chunk has 66px height -> 500*66/100=330 area extent height ->1000+330=1330
-        # The second padded chunk has 67px height -> 500*67/100=335 area extent height ->1330+335=1665
-        # The first padded chunk has 67px height -> 500*67/100=335 area extent height ->1665+335=2000
-        self.assertEqual(AreaDefinition.call_count, 5)
+        # The first segment has 100px height and 500 area extent height.
+        # The first padded segment has 66px height -> 500*66/100=330 area extent height ->1000+330=1330
+        # The second padded segment has 67px height -> 500*67/100=335 area extent height ->1330+335=1665
+        # The first padded segment has 67px height -> 500*67/100=335 area extent height ->1665+335=2000
+        assert fake_adef.call_count == 5
         expected_call1 = ('fill', 'fill', 'fill', 'some_crs', 11136, 100,
                           (0, 1500.0, 200, 1000))
         expected_call2 = ('fill', 'fill', 'fill', 'some_crs', 11136, 100,
@@ -1467,13 +1484,13 @@ class TestGEOVariableSegmentYAMLReader(unittest.TestCase):
         expected_call5 = ('fill', 'fill', 'fill', 'some_crs', 11136, 67,
                           (0, 2000.0, 200, 1665.0))
 
-        AreaDefinition.side_effect = None
-        AreaDefinition.assert_has_calls([call(*expected_call1),
-                                         call(*expected_call2),
-                                         call(*expected_call3),
-                                         call(*expected_call4),
-                                         call(*expected_call5)
-                                         ])
+        fake_adef.side_effect = None
+        fake_adef.assert_has_calls([call(*expected_call1),
+                                    call(*expected_call2),
+                                    call(*expected_call3),
+                                    call(*expected_call4),
+                                    call(*expected_call5)
+                                    ])
 
     def test_get_empty_segment_with_height(self):
         """Test _get_empty_segment_with_height()."""
