@@ -93,10 +93,9 @@ class TestNinjoTIFFWriter(unittest.TestCase):
         img = FakeImage(dataset, 'L')
         ret = ntw.save_image(img, filename='bla.tif', compute=False)
         nt.save.assert_called()
-        assert(nt.save.mock_calls[0][2]['compute'] is False)
-        assert(nt.save.mock_calls[0][2]['ch_min_measurement_unit']
-               < nt.save.mock_calls[0][2]['ch_max_measurement_unit'])
-        assert(ret == nt.save.return_value)
+        assert nt.save.mock_calls[0][2]['compute'] is False
+        assert nt.save.mock_calls[0][2]['ch_min_measurement_unit'] < nt.save.mock_calls[0][2]['ch_max_measurement_unit']
+        assert ret == nt.save.return_value
 
     def test_convert_units_self(self):
         """Test that unit conversion to themselves do nothing."""
