@@ -159,9 +159,7 @@ class GeoTIFFWriter(ImageWriter):
     ):
         """Save the image to the given ``filename`` in geotiff_ format.
 
-        Note for faster output and reduced memory usage the ``rasterio``
-        library must be installed. This writer currently falls back to
-        using ``gdal`` directly, but that will be deprecated in the future.
+        Note this writer requires the ``rasterio`` library to be installed.
 
         Args:
             img (xarray.DataArray): Data to save to geotiff.
